pub struct AgentEndpoint {
pub agent_id: String,
pub phase: Option<String>,
pub task_id: Option<String>,
pub item_id: Option<String>,
}Expand description
Address of an agent or a specific agent execution scope.
Fields
agent_id: StringAgent identifier.
phase: Option<String>Optional phase scope.
task_id: Option<String>Optional task scope.
item_id: Option<String>Optional task-item scope.
Implementations
Sourceimpl AgentEndpoint
impl AgentEndpoint
Sourcepub fn agent(agent_id: &str) -> AgentEndpoint
pub fn agent(agent_id: &str) -> AgentEndpoint
Creates an endpoint scoped only to an agent identifier.
Sourcepub fn for_phase(agent_id: &str, phase: &str) -> AgentEndpoint
pub fn for_phase(agent_id: &str, phase: &str) -> AgentEndpoint
Creates an endpoint scoped to a specific agent phase.
Sourcepub fn for_task_item(
agent_id: &str,
task_id: &str,
item_id: &str,
) -> AgentEndpoint
pub fn for_task_item( agent_id: &str, task_id: &str, item_id: &str, ) -> AgentEndpoint
Creates an endpoint scoped to a specific task item.