pub enum ExecutionMode {
Agent,
Builtin {
name: String,
},
Chain,
}Expand description
How a step is executed.
Variants
Agent
Execute the step by selecting an agent with the required capability.
Builtin
Execute one builtin step implementation.
Chain
Execute a sequence of child steps inside one chain step.