pub struct ItemSelectConfig {
pub strategy: SelectionStrategy,
pub metric_var: Option<String>,
pub weights: Option<HashMap<String, f64>>,
pub threshold: Option<f64>,
pub store_result: Option<StoreTarget>,
pub tie_break: TieBreak,
}Expand description
WP03: Configuration for the item_select builtin step.
Fields
strategy: SelectionStrategySelection strategy.
metric_var: Option<String>Pipeline variable name containing the metric to evaluate (for min/max/threshold).
weights: Option<HashMap<String, f64>>Weight map for weighted strategy: var_name → weight.
threshold: Option<f64>Threshold value (for threshold strategy).
store_result: Option<StoreTarget>Where to persist the selection result in the workflow store.
tie_break: TieBreakHow to break ties (default: first).