pub struct WorkspaceConfig {
pub root_path: String,
pub qa_targets: Vec<String>,
pub ticket_dir: String,
pub self_referential: bool,
pub health_policy: HealthPolicyConfig,
}Expand description
Workspace configuration
Fields
root_path: StringPath to the workspace root, relative to the application root unless absolute.
qa_targets: Vec<String>QA target paths evaluated for this workspace.
ticket_dir: StringDirectory used to store QA tickets for the workspace.
self_referential: boolWhen true, the workspace points to the orchestrator’s own source tree
health_policy: HealthPolicyConfigDefault health policy for agents operating in this workspace.