AppliedMigrationSummary

Struct AppliedMigrationSummary 

pub struct AppliedMigrationSummary {
    pub applied: Vec<MigrationDescriptor>,
}
Summarizes which migrations were applied during a run_pending invocation.

Fields

applied: Vec<MigrationDescriptor>

Ordered descriptors for migrations applied in the current run.

Implementations

Source

impl AppliedMigrationSummary

pub fn count(&self) -> u32

Returns the number of migrations applied in the current run.

pub fn is_empty(&self) -> bool

Returns true when no migrations were applied.