pub struct KeyRing { /* private fields */ }Expand description
Loaded key material plus lifecycle metadata used by SecretStore operations.
Implementations
Sourceimpl KeyRing
impl KeyRing
Sourcepub fn active_key(&self) -> Result<&SecretKeyHandle, Error>
pub fn active_key(&self) -> Result<&SecretKeyHandle, Error>
Returns the active key used for new encryption operations.
Sourcepub fn decrypt_key(&self, key_id: &str) -> Result<&SecretKeyHandle, Error>
pub fn decrypt_key(&self, key_id: &str) -> Result<&SecretKeyHandle, Error>
Returns a decryption key for the requested key identifier.
Sourcepub fn all_records(&self) -> &[KeyRecord]
pub fn all_records(&self) -> &[KeyRecord]
Returns every persisted key record in load order.
Sourcepub fn active_record(&self) -> Option<&KeyRecord>
pub fn active_record(&self) -> Option<&KeyRecord>
Returns the active key record, if any.
Sourcepub fn has_active_key(&self) -> bool
pub fn has_active_key(&self) -> bool
Returns true when an active encryption key is available.
Sourcepub fn decrypt_only_records(&self) -> Vec<&KeyRecord>
pub fn decrypt_only_records(&self) -> Vec<&KeyRecord>
Returns all records currently in the decrypt-only state.
Sourcepub fn decrypt_keys_iter(
&self,
) -> impl Iterator<Item = (&str, &SecretKeyHandle)>
pub fn decrypt_keys_iter( &self, ) -> impl Iterator<Item = (&str, &SecretKeyHandle)>
Iterates over key identifiers and handles that can decrypt existing payloads.