pub struct ConfigRuntimeSnapshot {
pub active_config: Arc<ActiveConfig>,
pub active_config_error: Option<String>,
pub active_config_notice: Option<ConfigSelfHealReport>,
}Expand description
Snapshot of the currently active configuration and its status.
Fields
active_config: Arc<ActiveConfig>Active runtime configuration.
active_config_error: Option<String>Optional validation or load error for the active config.
active_config_notice: Option<ConfigSelfHealReport>Optional self-heal notice associated with the active config.
Implementations
Sourceimpl ConfigRuntimeSnapshot
impl ConfigRuntimeSnapshot
Sourcepub fn new(
active_config: ActiveConfig,
active_config_error: Option<String>,
active_config_notice: Option<ConfigSelfHealReport>,
) -> Self
pub fn new( active_config: ActiveConfig, active_config_error: Option<String>, active_config_notice: Option<ConfigSelfHealReport>, ) -> Self
Creates a runtime snapshot from configuration and status values.