pub struct RunningTask {
pub stop_flag: Arc<AtomicBool>,
pub child: Arc<Mutex<Option<Child>>>,
}Expand description
Mutable runtime handle for a task process.
Fields
stop_flag: Arc<AtomicBool>Shared stop flag observed by all forked execution branches.
child: Arc<Mutex<Option<Child>>>Handle to the currently running child process, if any.
Implementations