pub struct TriggerEngineHandle { /* private fields */ }Expand description
Handle used by the rest of the system to communicate with a running engine.
Implementations
Sourceimpl TriggerEngineHandle
impl TriggerEngineHandle
Sourcepub fn reload_sync(&self) -> bool
pub fn reload_sync(&self) -> bool
Notify the engine to reload trigger configuration (sync-safe).
Uses try_send so it can be called from synchronous code paths
like apply_manifests. Returns true if the notification was sent.