pub struct OrchestratorError { /* private fields */ }Expand description
Canonical error type returned by public orchestrator APIs.
Implementations
Sourceimpl OrchestratorError
impl OrchestratorError
Sourcepub fn new(
category: ErrorCategory,
operation: &'static str,
source: impl Into<AnyError>,
) -> Self
pub fn new( category: ErrorCategory, operation: &'static str, source: impl Into<AnyError>, ) -> Self
Builds an error with an explicit category and operation label.
Sourcepub fn with_subject(self, subject: impl Into<String>) -> Self
pub fn with_subject(self, subject: impl Into<String>) -> Self
Attaches an optional resource or subject identifier to the error.
Sourcepub fn category(&self) -> ErrorCategory
pub fn category(&self) -> ErrorCategory
Returns the assigned error category.
Sourcepub fn user_input(operation: &'static str, source: impl Into<AnyError>) -> Self
pub fn user_input(operation: &'static str, source: impl Into<AnyError>) -> Self
Builds a ErrorCategory::UserInput error.
Sourcepub fn config_validation(
operation: &'static str,
source: impl Into<AnyError>,
) -> Self
pub fn config_validation( operation: &'static str, source: impl Into<AnyError>, ) -> Self
Builds a ErrorCategory::ConfigValidation error.
Sourcepub fn not_found(operation: &'static str, source: impl Into<AnyError>) -> Self
pub fn not_found(operation: &'static str, source: impl Into<AnyError>) -> Self
Builds a ErrorCategory::NotFound error.
Sourcepub fn invalid_state(
operation: &'static str,
source: impl Into<AnyError>,
) -> Self
pub fn invalid_state( operation: &'static str, source: impl Into<AnyError>, ) -> Self
Builds a ErrorCategory::InvalidState error.
Sourcepub fn security_denied(
operation: &'static str,
source: impl Into<AnyError>,
) -> Self
pub fn security_denied( operation: &'static str, source: impl Into<AnyError>, ) -> Self
Builds a ErrorCategory::SecurityDenied error.
Sourcepub fn external_dependency(
operation: &'static str,
source: impl Into<AnyError>,
) -> Self
pub fn external_dependency( operation: &'static str, source: impl Into<AnyError>, ) -> Self
Builds a ErrorCategory::ExternalDependency error.
Sourcepub fn internal_invariant(
operation: &'static str,
source: impl Into<AnyError>,
) -> Self
pub fn internal_invariant( operation: &'static str, source: impl Into<AnyError>, ) -> Self
Builds a ErrorCategory::InternalInvariant error.